% This program is used to segment the images from the Zebrafish heart.
% Nodal points of the wall and outlets are created for 2D simulations
% Place this file in the same folder as the image files to be segmented
%
% Press any key to pick points, "enter" to finish.  Start at the inlet end of
% the wall and finish at the outlet end.  Do this twice for each image to pick 
% the two sides of the wall.
%
% Use this program to segment when there is both an inlet and an outlet
% that need to be simulated.  
%
% In this update, the .dat file is now generated by a separate script
% "two_smooth.m" after all of the .bdr files are produced and temporal
% smoothing can be performed across all the wall motion
%
% For additional information, please see corresponding paper:
%
% 'Moving Domain Computational Fluid Dynamics to Interface with An Embryonic 
% Model of Cardiac Morphogenesis'
% by Juhyun Lee, Mahdi Esmaily-moghadam, Ethan Kung, Hung Cao, Tyler
% Beebe, Yury Miller, Beth L. Roman, Ching-Ling Lien, Neil C. Chi, Alison
% L. Marsden, and Tzung K. Hsiai

close all
clear;  clc;


% --------- This is the information user needs to enter -----------
name= 'deadfish';  % Desired output file name
xscale= ?;     % Image scale: cm (or whatever unit using for simulation) per pixel
yscale= ?;      % Image scale: cm (or whatever unit using for simulation) per pixel
timescale= ?;  
outn=? ;  % set number of points for outlet
inn=?   ; % set number of points for inlet
walln=?;  % set # of points for each wall
fineneg=?;  % increase this number to get a coarser mesh.  Must be integer
nstep=? ;  % number of wall motion steps to construct
reframe=? ;  % reference frame (use frame with minimal ventricle width)
% ------------------------------------------------------------------


filelist= dir('*.jpg');
delete([name '.dat']);


temp=imread(filelist(1).name); %load one pic to get image size
figure('Position',[100 -200, length(temp(1,:,1))*3 length(temp(:,1,1))*3]); %enlarge pic by proportion 
button= 'No';
for k=1:numel(filelist)
    while length(button)==2
        temp=imread(filelist(k).name);
%        data=temp(:,:,1) ;   %need to do this for RGB images
        
        image(temp);  [x,y]=ginput;  % pick wall points
        n=length(x);  % # of user picked wall points
        
        image(temp);  [x2,y2]=ginput;  % pick wall points
        n2=length(x2);  % # of user picked wall points       
        
        % Generate outlet nodes
        inlet=[ x(1) y(1); x2(1) y2(1);];
        inlet= createCurve( inlet(:,1), inlet(:,2), inn+2);        
        outlet=[ x(n) y(n); x2(n2) y2(n2);];
        outlet= createCurve( outlet(:,1), outlet(:,2), outn+2);
        
        % Generate wall nodes from user picked nodes
        nodes= createCurve(x,y,walln);
        nodes=[nodes; createCurve(x2,y2,walln)];
        
        %         %let user see where points were picked
        %         temp= data;
        %         for i=1:n
        %             temp(uint16(y(i)), uint16(x(i)))=255;
        %         end
        
        %let user see the generated wall points
        for i=1:walln*2
            temp(uint16(nodes(i,2)), uint16(nodes(i,1)))=255;
        end
        
        %         %let user see where outlet points are
        %         for i=1:outn
        %             temp(uint16(outlet(i,2)), uint16(outlet(i,1)))=255;
        %         end
        image(temp);
        
        button = questdlg('Are the points satisfactory?');
    end
    
    
    % Write out wall/outlet results
    % ID= 1. Wall  2. Outlet  3.Shared/Out   4. Interior  5. Inlet  6.
    % Shared/In
    noden=zeros(walln,1) +1;  %dummy column for wall node ID
    noden(1)= 6;  noden(end)=3;  % shared nodes
    nodes= [nodes [noden; noden] ];   % wall nodes
    
    noden=zeros(outn,1) +2;  %dummy column for outlet node ID
    nodes= [ nodes; outlet(2:outn+1,:) noden];  %add outlet nodes
    noden=zeros(inn,1) +5;  %dummy column for inlet node ID
    nodes= [ nodes; inlet(2:inn+1,:) noden];  %add inlet nodes
    
    
    outfile= regexprep( filelist(k).name ,'\D','');  %extract # from string!! useful command
    csvwrite([num2str(outfile) '.bdr'], nodes);
    button= 'No';
    
    
    
    
    if k==reframe
        %csvwrite('init_wall',nodes(1:walln,1:2));   
        two_meshing_alt
        figure('Position',[100 -200, length(temp(1,:,1))*3 length(temp(:,1,1))*3]); %create seg figure again 
    end
    
            
end


%delete('init_wall');

two_smooth   %generate the wall motion .dat file



