% This file reads in user-segmented wall motion information from .bdr files
% and smoothes the movements temporally.  Then writes out the smoothed
% displacement into a .dat file for simulation
% Added/corrected line (66) to remove missing nodes  5/7/2013
% Added check for empty .bdr element 5/6/2013
% For additional information, please see corresponding paper:
%
% 'Moving Domain Computational Fluid Dynamics to Interface with An Embryonic 
% Model of Cardiac Morphogenesis'
% by Juhyun Lee, Mahdi Esmaily-moghadam, Ethan Kung, Hung Cao, Tyler
% Beebe, Yury Miller, Beth L. Roman, Ching-Ling Lien, Neil C. Chi, Alison
% L. Marsden, and Tzung K. Hsiai



% need to set these values if using this file standalone
% these values MUST be the same as whatever used in the "segmentation" script
% ------------------------------------------------------------------
if ~exist('walln')
name= 'deadfish';  % Desired output file name
xscale= ?;     % Image scale: cm (or whatever unit using for simulation) per pixel
yscale= ?;      % Image scale: cm (or whatever unit using for simulation) per pixel
timescale= ?;  
walln=?;  % set # of points for each wall
nstep=? ;  % number of wall motion steps to construct
reframe=? ;  % reference frame (use frame with minimal ventricle width)
end
% ------------------------------------------------------------------




delete([name '.dat']);
bdrlist= dir('*.bdr');
nbdr= numel(bdrlist);   % number of bdr files


% read in all bdr information 
xcoord=zeros(walln*2,nbdr);
ycoord=zeros(walln*2,nbdr);
for nb=1:nbdr  %loop through all .bdr files

    if ~strcmp( bdrlist(nb).name, '.bdr' )  %what the hell, sometimes get a empty element in bdr list
    
time(nb)= str2num(regexprep( bdrlist(nb).name ,'\D',''));  %record current bdr timestamp
temp= load(bdrlist(nb).name);   %load current bdr

for i=1:walln*2   %read in all the x,y coordinate data - vertical points, horizontal time
   xcoord(i,nb)=temp(i,1);
   ycoord(i,nb)=temp(i,2);
end

    end

end


% Calculate smoothed curves of x and y coordinates
timeaxis = linspace(time(1), time(end), nstep);  %generate time axis for smoothed curve
outputx=zeros(walln*2, length(timeaxis));
outputy=zeros(walln*2, length(timeaxis));
for i=1:walln*2
outputx(i,:) = spline(time,xcoord(i,:),timeaxis);
outputy(i,:) = spline(time,ycoord(i,:),timeaxis);
end

% write out smoothed displacements
refx=xcoord(:,reframe);  %initial node position at time 0 for reference
refy=ycoord(:,reframe);

fid5=fopen([name '.dat'],'w');
fprintf(fid5,'%d %d\n',nstep,walln*2 - sum(deadNode(1:walln*2)) );  %print first line: num steps, num wall nodes

for nb=1:nstep
fprintf(fid5,'%.16f \n', (timeaxis(nb)-timeaxis(1))*timescale );  %print current time
for i=1:walln*2
    if deadNode(i) == 0  %skip the nodes that were removed during meshing
    xnew= ( outputx(i,nb)- refx(i) )*xscale;  %relative position compared to the initial location of the node
    ynew= (outputy(i,nb)- refy(i) )*yscale ;
    fprintf(fid5,'%.16f %.16f \n',ynew,xnew);
    end
end
end

fclose(fid5);


